/*
 * Copyright (C) 2006-2009 Andre Noll <maan@systemlinux.org>
 *
 * Licensed under the GPL v2. For licencing details see COPYING.
 */

/** \file audiod.h symbols exported from audiod.c */


int num_filters(int audio_format_num);
int get_audio_format_num(const char *name);

/** enum of audio formats supported by para_audiod */
enum {AUDIOD_AUDIO_FORMATS_ENUM};

/** array of audio format names supported by para_audiod */
extern const char *audio_formats[];

/** maximal number of simultaneous instances */
#define MAX_STREAM_SLOTS 5

/**
 * the possible modes of operation
 *
 * - off: disconnect from para_server
 * - on: receive status information from para_server and play the audio stream
 * - sb: only receive status information but not the audio stream
 */
enum audiod_status_info {AUDIOD_OFF, AUDIOD_ON, AUDIOD_STANDBY};

/** defines one command of para_audiod */
struct audiod_command {
	/** the name of the command */
	const char *name;
	/** pointer to the function that handles the command */
	int (*handler)(int, int, char**);
	/** one-line description of the command */
	const char *description;
	/** summary of the command line options */
	const char *usage;
	/** the long help text */
	const char *help;
};

/**
 * Describes one instance of a receiver-filter-writer chain.
 *
 * \sa receiver_node, receiver, filter, filter_node, filter_chain, writer,
 * writer_node, writer_node_group.
 */
struct slot_info {
	/** Number of the audio format in this slot. */
	int format;
	/** Receiver start time. */
	struct timeval rstime;
	/** Writer start time. */
	struct timeval wstime;
	/** The stream_start status item announced by para_server.  */
	struct timeval server_stream_start;
	/** The offset status item announced by para_server. */
	unsigned offset_seconds;
	/** The seconds_total status item announced by para_server. */
	unsigned seconds_total;
	/** The receiver info associated with this slot. */
	struct receiver_node *receiver_node;
	/** The active filter chain. */
	struct filter_chain *fc;
	/** The active writer node group. */
	struct writer_node_group *wng;
};

extern struct slot_info slot[MAX_STREAM_SLOTS];
extern struct audiod_args_info conf;
extern int audiod_status;

void __noreturn clean_exit(int status, const char *msg);
int handle_connect(int accept_fd);
void audiod_status_dump(void);
char *get_time_string(int slot_num);

void stat_client_write_item(int item_num);
void clear_and_dump_items(void);

/** iterate over all slots */
#define FOR_EACH_SLOT(_slot) for (_slot = 0; _slot < MAX_STREAM_SLOTS; _slot++)
