/*
 * Copyright (C) 1997-2009 Andre Noll <maan@systemlinux.org>
 *
 * Licensed under the GPL v2. For licencing details see COPYING.
 */

/** \file client.h Common client functions and exported symbols from client_common.c. */

#include <openssl/rc4.h>

/** The different states of a connection from the view of the client. */
enum {
	/** TCP connection is established. */
	CL_CONNECTED,
	/** Server sends the welcome message. */
	CL_RECEIVED_WELCOME,
	/** Client sends the authentification request. */
	CL_SENT_AUTH,
	/** Server sends a challenge. */
	CL_RECEIVED_CHALLENGE,
	/** Client solves the challenge and sends the result. */
	CL_SENT_CH_RESPONSE,
	/** Server accepts this authentication. */
	CL_RECEIVED_PROCEED,
	/** Client sends the command. */
	CL_SENT_COMMAND,
	/** Server expects data. */
	CL_SENDING,
	/** Client expects data. */
	CL_RECEIVING,
};

/** The size of the receiving buffer. */
#define CLIENT_BUFSIZE 8192

/** Data specific to a client task. */
struct client_task {
	/** The state of the connection. */
	int status;
	/** The file descriptor and the rc4 keys. */
	struct rc4_context rc4c;
	/** The configuration (including the command). */
	struct client_args_info conf;
	/** The config file for client options. */
	char *config_file;
	/** The RSA private key. */
	char *key_file;
	/** Paraslash user name. */
	char *user;
	/** The client task structure. */
	struct task task;
	/** The buffer used for handshake and receiving. */
	char *buf;
	/** Number of bytes loaded in \a buf. */
	size_t loaded;
	/** Non-zero if the pre_select hook added \a fd to the read fd set. */
	int check_r;
	/** Non-zero if the pre_select hook added \a fd to the write fd set. */
	int check_w;
	/** Pointer to the data to be sent to para_server. */
	char *inbuf;
	/** Number of bytes loaded in \a inbuf. */
	size_t *in_loaded;
	/** Non-zero if input task encountered an eof or an error condition. */
	int *in_error;
};

void client_close(struct client_task *ct);
int client_open(int argc, char *argv[], struct client_task **ct,
		int *loglevel);
